
:mod:`numina.core.oresult` --- Observation Result
==================================================

.. automodule:: numina.core.oresult
   :members:

:mod:`numina.core.taggers` --- Extract information from OBs
============================================================

.. automodule:: numina.core.taggers
   :members: